@@ -10,11 +10,16 @@ motdepasse = Blueprint('motdepasse', __name__, url_prefix = '/motdepasse')
 def show():
 
     username = session["username"]
+    session["admin_etab"] = False
     is_prof = utils.est_prof()
     is_admin = False
+    is_admin_etab = False
     if utils.est_admin():
         is_admin = True
-        
+    if utils.est_admin_etab():
+        is_admin_etab = True
+        session["admin_etab"] = True
+
     if not is_prof:
         current_app.logger.warning('User %s (not prof) tried to access page \'motdepasse.html\'.' %username)
         return render_template('erreurs/non_prof.html', username=username)
@@ -25,6 +30,7 @@ def show():
                                nb_car_min = current_app.config['NB_CAR_MIN'],
                                username = username,
                                is_admin = is_admin,
+                               is_admin_etab = is_admin_etab,
                                url_logout = url_logout,
                                activer_ad = current_app.config['ACTIVER_AD'],
                                multi_etab = current_app.config['MULTI_ETAB'])
